@@ -1,6 +1,7 @@
 package App::SimpleScan::Plugin::Tester;
 
 sub options {
+  # Test that the option handler unpacks this correctly.
   ['tester', \$tester];
 }
 
@@ -15,3 +16,4 @@ sub test_modules {
 sub per_test_code {
   return (qq(diag "test code inserted"));
 }
+1;
